package com.jh.common.security.repository;

import javax.persistence.Query;

import org.springframework.util.StringUtils;

import com.jh.common.jpa.AbstractHibernateRepository;
import com.jh.common.security.PasswordHash;
import com.jh.common.security.PasswordUtils;
import com.jh.common.security.model.AppUser;


public class AppUserRepository extends AbstractHibernateRepository {

	public AppUser findByLogin(String username) {
		if (!StringUtils.hasText(username)) {
			return null;
		}
		Query q = entityManager.createQuery("select au from AppUser au where lower(au.email) = :email");
		q.setParameter("email", username.trim().toLowerCase());
		return singleResult(q);
	}
	
	
	public AppUser registerUser(String username, String password) {
		AppUser user = new AppUser();
		user.setEmail(username);
		
		PasswordHash hash = PasswordUtils.hashPassword(password);
		user.setPassword(hash.getHash());
		user.setPasswordSalt(hash.getSalt());
		
		entityManager.persist(user);
		
		return user;
	}
	
}
