package com.jh.common.security.service;

import java.util.HashSet;
import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import com.jh.common.security.AuthService;
import com.jh.common.security.GrantedRole;
import com.jh.common.security.PasswordUtils;
import com.jh.common.security.model.AppUser;
import com.jh.common.security.repository.AppUserRepository;



public class AppUserAuthService implements AuthService {

	
	private AppUserRepository appUserRepository;

	@Override
	@Transactional
	public Authentication authenticate(String login, String password) throws BadCredentialsException {
		AppUser user = appUserRepository.findByLogin(login);
		if (user == null) {
			throw new BadCredentialsException("User not found");
		}
		if (!PasswordUtils.checkPassword(password, user.getPassword(), user.getPasswordSalt())) {
			throw new BadCredentialsException("Bad password");
		}
		
		Set<GrantedRole> roles = new HashSet<>();
		
		UsernamePasswordAuthenticationToken auth = new UsernamePasswordAuthenticationToken(user.getEmail(), user.getPassword(), roles);
		return auth;
	}

	@Override
	@Transactional
	public void register(String login, String password) throws AuthenticationException {
		AppUser user = appUserRepository.findByLogin(login);
		if (user != null) {
			throw new BadCredentialsException("User already exists");
		}
		if (!StringUtils.hasText(login) || !StringUtils.hasText(password)) {
			throw new BadCredentialsException("Bad username or password");
		}
		appUserRepository.registerUser(login, password);
	}

	@Override
	@Transactional
	public String generateResetToken(String login) {
		return "TOKEN";
	}

	@Override
	@Transactional
	public void resetPassword(String login, String token, String newPassword) throws AuthenticationException {
	}
	
	@Autowired(required = false)
	public void setAppUserRepository(AppUserRepository appUserRepository) {
		this.appUserRepository = appUserRepository;
	}
	
}
